@@ -12,20 +12,12 @@
 
 K_PLUGIN_CLASS(RdpPreferences)
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-RdpPreferences::RdpPreferences(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
 RdpPreferences::RdpPreferences(QObject *parent)
     : KCModule(parent)
-#endif
 {
     Ui::RdpPreferences rdpUi;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    rdpUi.setupUi(this);
-#else
     rdpUi.setupUi(widget());
-#endif
+
     // would need a lot of code duplication. find a solution, but it's not
     // that important because you will not change this configuration each day...
     // see rdp/rdphostpreferences.cpp
@@ -35,11 +27,7 @@ RdpPreferences::RdpPreferences(QObject *parent)
     rdpUi.heightLabel->setEnabled(true);
     rdpUi.widthLabel->setEnabled(true);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    addConfig(Settings::self(), this);
-#else
     addConfig(Settings::self(), widget());
-#endif
 }
 
 RdpPreferences::~RdpPreferences()
